@@ -10,15 +10,15 @@ import traceback
 import os
 
 class CloudFront:
-    def __init__(self, content_manager:ContentManager, app:Chalice):
-        """
-        Supports caching via CloudFront for the following usecases:
-        - Jinja2 Templates by exploring dependancy trees of templates and their arguments.
-        - Static content by extracting modified dates from static content.
+    """
+    Supports caching via CloudFront for the following usecases:
+    - Jinja2 Templates by exploring dependancy trees of templates and their arguments.
+    - Static content by extracting modified dates from static content.
 
-        :param content_manager: challice_http_toolkit.ContentManager
-        :returns: CloudFront instance
-        """
+    :param content_manager: challice_http_toolkit.ContentManager
+    :returns: CloudFront instance
+    """
+    def __init__(self, content_manager:ContentManager, app:Chalice):
         self.__fsl = FileSystemLoader(content_manager.templates_dir)
         self.__cm = content_manager
         self.__app = app
@@ -80,6 +80,9 @@ class CloudFront:
         :param kwargs: Keyword arguments to be passed to template in the event that it is rendered, must be pickleable
         :returns: Chalice Response object
         """
+        if self.__app.current_request is None:
+            return self.__cm.html(self.__cm.render_template(filename, **kwargs), status_code=status_code, headers=headers)
+
         if_none_match = self.__app.current_request.headers.get('If-None-Match')
         print(f'If-None-Match: {if_none_match}')
         try:
@@ -111,6 +114,9 @@ class CloudFront:
         :param cache_control: Controls how CloudFront manages re-evaluating the orgin. See https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/Expiration.html and https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Cache-Control.
         :returns: Chalice Response object
         """
+        if self.__app.current_request is None:
+            return self.__cm.static(filename, status_code=status_code, headers=headers)
+
         if_modified_since = self.__app.current_request.headers.get('If-Modified-Since')
         print(f'If-Modified-Since: {if_modified_since}')
         try:
@@ -147,6 +153,9 @@ class CloudFront:
         :param cache_control: Controls how CloudFront manages re-evaluating the orgin. See https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/Expiration.html and https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Cache-Control.
         :returns: Chalice Response object
         """
+        if self.__app.current_request is None:
+            return self.__cm.asset(get_asset(), status_code=status_code, headers=headers)
+
         if_none_match = self.__app.current_request.headers.get('If-None-Match')
         print(f'If-None-Match: {if_none_match}')
         try:
