@@ -3,7 +3,7 @@ import os
 import io
 import base64
 from typing import Optional
-from chalice import Response
+from chalice import Response, Chalice
 from magic import Magic
 from chalice_http_toolkit.response_with_binary import ResponseWithBinary
 import json
@@ -17,15 +17,17 @@ class ContentManager:
 
     :param templates_dir: Base path for templates
     :param static_dir: Base path for static content
+    :param app: Chalice app
     :param magic: Optional python-magic instance, often required given Lambda hosts dont have libmagic installed.
     :returns: ContentManager instance
     """
-    def __init__(self, templates_dir:str, static_dir:str, magic:Optional[Magic]=None):
+    def __init__(self, templates_dir:str, static_dir:str, app:Chalice, magic:Optional[Magic]=None):
         self.templates_dir = templates_dir
         self.static_dir = static_dir
         self.__allowed_static_files = os.listdir(static_dir)
         self.env = jinja2.Environment(loader=jinja2.FileSystemLoader(templates_dir))
         self.__magic = magic if magic else Magic(mime=True)
+        self.__app = app
 
     def set_static_handler_prefix(self, path:str):
         """
@@ -122,6 +124,11 @@ class ContentManager:
 
         isBase64Encoded = False
         if content_type.startswith('image/'):
+            if self.__app.current_request:
+                accepts = self.__app.current_request.headers.get('accept', '')
+                if accepts:
+                    body = self.convert_by_accepts(body, accepts)
+                    content_type = self.__magic.from_buffer(body)
             body = base64.b64encode(body)
             isBase64Encoded = True
         h["Content-Type"] = content_type
