@@ -1,5 +1,6 @@
 from chalice import Response
 import os
+import base64
 
 class ResponseWithBinary(Response):
     """
@@ -11,6 +12,10 @@ class ResponseWithBinary(Response):
     isLocal = os.environ.get('STAGE', 'dev') == 'dev'
     def to_dict(self, binary_types=None) -> dict:
         response = super().to_dict(binary_types=binary_types)
-        if self.isBase64Encoded and not self.isLocal:
+        if self.isLocal:
+            if self.isBase64Encoded:
+                response['body'] = base64.b64decode(response['body'])
+            response['isBase64Encoded'] = False
+        elif self.isBase64Encoded:
             response['isBase64Encoded'] = True
         return response
\ No newline at end of file
